=========
Changelog
=========

.. _v1.1.0:

1.1.0 - September 25, 2019
~~~~~~~~~~~~~~~~~~~~~~~~~~

* Add TLS support to the SLUGS API endpoints
* Add Python 3.7 support
* Add Ubuntu 16.04 LTS testing support
* Update dependencies to minimize upstream build errors

.. _v1.0.0:

1.0.0 - March 15, 2018
~~~~~~~~~~~~~~~~~~~~~~

* Initial release

.. _`master`: https://github.com/openkmip/slugs/
